@@ -29,6 +29,7 @@ from typing import Any, Dict, List, Mapping, Optional, Protocol, TYPE_CHECKING,
 
 from . import utils
 from .colour import Colour
+from .flags import AttachmentFlags, EmbedFlags
 
 # fmt: off
 __all__ = (
@@ -76,6 +77,7 @@ if TYPE_CHECKING:
         proxy_url: Optional[str]
         height: Optional[int]
         width: Optional[int]
+        flags: Optional[AttachmentFlags]
 
     class _EmbedVideoProxy(Protocol):
         url: Optional[str]
@@ -131,7 +133,7 @@ class Embed:
         The type of embed. Usually "rich".
         This can be set during initialisation.
         Possible strings for embed types can be found on discord's
-        :ddocs:`api docs <resources/channel#embed-object-embed-types>`
+        :ddocs:`api docs <resources/message#embed-object-embed-types>`
     description: Optional[:class:`str`]
         The description of the embed.
         This can be set during initialisation.
@@ -146,6 +148,10 @@ class Embed:
     colour: Optional[Union[:class:`Colour`, :class:`int`]]
         The colour code of the embed. Aliased to ``color`` as well.
         This can be set during initialisation.
+    flags: Optional[:class:`EmbedFlags`]
+        The flags of this embed.
+
+        .. versionadded:: 2.5
     """
 
     __slots__ = (
@@ -162,6 +168,7 @@ class Embed:
         '_author',
         '_fields',
         'description',
+        'flags',
     )
 
     def __init__(
@@ -181,6 +188,7 @@ class Embed:
         self.type: EmbedType = type
         self.url: Optional[str] = url
         self.description: Optional[str] = description
+        self.flags: Optional[EmbedFlags] = None
 
         if self.title is not None:
             self.title = str(self.title)
@@ -199,7 +207,7 @@ class Embed:
         """Converts a :class:`dict` to a :class:`Embed` provided it is in the
         format that Discord expects it to be in.
 
-        You can find out about this format in the :ddocs:`official Discord documentation <resources/channel#embed-object>`.
+        You can find out about this format in the :ddocs:`official Discord documentation <resources/message#embed-object>`.
 
         Parameters
         -----------
@@ -245,6 +253,11 @@ class Embed:
             else:
                 setattr(self, '_' + attr, value)
 
+        try:
+            self.flags = EmbedFlags._from_value(data['flags'])
+        except KeyError:
+            pass
+
         return self
 
     def copy(self) -> Self:
@@ -399,11 +412,15 @@ class Embed:
         - ``proxy_url``
         - ``width``
         - ``height``
+        - ``flags``
 
         If the attribute has no value then ``None`` is returned.
         """
         # Lying to the type checker for better developer UX.
-        return EmbedProxy(getattr(self, '_image', {}))  # type: ignore
+        data = getattr(self, '_image', {})
+        if 'flags' in data:
+            data['flags'] = AttachmentFlags._from_value(data['flags'])
+        return EmbedProxy(data)  # type: ignore
 
     def set_image(self, *, url: Optional[Any]) -> Self:
         """Sets the image for the embed content.
@@ -413,8 +430,9 @@ class Embed:
 
         Parameters
         -----------
-        url: :class:`str`
+        url: Optional[:class:`str`]
             The source URL for the image. Only HTTP(S) is supported.
+            If ``None`` is passed, any existing image is removed.
             Inline attachment URLs are also supported, see :ref:`local_image`.
         """
 
@@ -452,13 +470,11 @@ class Embed:
         This function returns the class instance to allow for fluent-style
         chaining.
 
-        .. versionchanged:: 1.4
-            Passing ``None`` removes the thumbnail.
-
         Parameters
         -----------
-        url: :class:`str`
+        url: Optional[:class:`str`]
             The source URL for the thumbnail. Only HTTP(S) is supported.
+            If ``None`` is passed, any existing thumbnail is removed.
             Inline attachment URLs are also supported, see :ref:`local_image`.
         """
 
