@@ -25,6 +25,7 @@ from __future__ import annotations
 
 import inspect
 import discord
+import logging
 from discord import app_commands
 from discord.utils import maybe_coroutine, _to_kebab_case
 
@@ -65,6 +66,7 @@ __all__ = (
 FuncT = TypeVar('FuncT', bound=Callable[..., Any])
 
 MISSING: Any = discord.utils.MISSING
+_log = logging.getLogger(__name__)
 
 
 class CogMeta(type):
@@ -167,7 +169,7 @@ class CogMeta(type):
     __cog_app_commands__: List[Union[app_commands.Group, app_commands.Command[Any, ..., Any]]]
     __cog_listeners__: List[Tuple[str, str]]
 
-    def __new__(cls, *args: Any, **kwargs: Any) -> Self:
+    def __new__(cls, *args: Any, **kwargs: Any) -> CogMeta:
         name, bases, attrs = args
         if any(issubclass(base, app_commands.Group) for base in bases):
             raise TypeError(
@@ -305,6 +307,7 @@ class Cog(metaclass=CogMeta):
 
         # Register the application commands
         children: List[Union[app_commands.Group, app_commands.Command[Self, ..., Any]]] = []
+        app_command_refs: Dict[str, Union[app_commands.Group, app_commands.Command[Self, ..., Any]]] = {}
 
         if cls.__cog_is_app_commands_group__:
             group = app_commands.Group(
@@ -315,6 +318,8 @@ class Cog(metaclass=CogMeta):
                 parent=None,
                 guild_ids=getattr(cls, '__discord_app_commands_default_guilds__', None),
                 guild_only=getattr(cls, '__discord_app_commands_guild_only__', False),
+                allowed_contexts=getattr(cls, '__discord_app_commands_contexts__', None),
+                allowed_installs=getattr(cls, '__discord_app_commands_installation_types__', None),
                 default_permissions=getattr(cls, '__discord_app_commands_default_permissions__', None),
                 extras=cls.__cog_group_extras__,
             )
@@ -331,6 +336,16 @@ class Cog(metaclass=CogMeta):
                 # Get the latest parent reference
                 parent = lookup[parent.qualified_name]  # type: ignore
 
+                # Hybrid commands already deal with updating the reference
+                # Due to the copy below, so we need to handle them specially
+                if hasattr(parent, '__commands_is_hybrid__') and hasattr(command, '__commands_is_hybrid__'):
+                    current: Optional[Union[app_commands.Group, app_commands.Command[Self, ..., Any]]] = getattr(
+                        command, 'app_command', None
+                    )
+                    updated = app_command_refs.get(command.qualified_name)
+                    if current and updated:
+                        command.app_command = updated  # type: ignore  # Safe attribute access
+
                 # Update our parent's reference to our self
                 parent.remove_command(command.name)  # type: ignore
                 parent.add_command(command)  # type: ignore
@@ -345,8 +360,15 @@ class Cog(metaclass=CogMeta):
                     # The type checker does not see the app_command attribute even though it exists
                     command.app_command = app_command  # type: ignore
 
+                    # Update all the references to point to the new copy
+                    if isinstance(app_command, app_commands.Group):
+                        for child in app_command.walk_commands():
+                            app_command_refs[child.qualified_name] = child
+                            if hasattr(child, '__commands_is_hybrid_app_command__') and child.qualified_name in lookup:
+                                child.wrapped = lookup[child.qualified_name]  # type: ignore
+
                     if self.__cog_app_commands_group__:
-                        children.append(app_command)  # type: ignore # Somehow it thinks it can be None here
+                        children.append(app_command)
 
         if Cog._get_overridden_method(self.cog_app_command_error) is not None:
             error_handler = self.cog_app_command_error
@@ -377,7 +399,7 @@ class Cog(metaclass=CogMeta):
             if len(mapping) > 25:
                 raise TypeError('maximum number of application command children exceeded')
 
-            self.__cog_app_commands_group__._children = mapping  # type: ignore  # Variance issue
+            self.__cog_app_commands_group__._children = mapping
 
         return self
 
@@ -753,7 +775,7 @@ class Cog(metaclass=CogMeta):
             try:
                 await maybe_coroutine(self.cog_unload)
             except Exception:
-                pass
+                _log.exception('Ignoring exception in cog unload for Cog %r (%r)', cls, self.qualified_name)
 
 
 class GroupCog(Cog):
