@@ -82,16 +82,20 @@ def is_cog(obj: Any) -> TypeGuard[Cog]:
     return hasattr(obj, '__cog_commands__')
 
 
-class DeferTyping:
+class DeferTyping(Generic[BotT]):
     def __init__(self, ctx: Context[BotT], *, ephemeral: bool):
         self.ctx: Context[BotT] = ctx
         self.ephemeral: bool = ephemeral
 
+    async def do_defer(self) -> None:
+        if self.ctx.interaction and not self.ctx.interaction.response.is_done():
+            await self.ctx.interaction.response.defer(ephemeral=self.ephemeral)
+
     def __await__(self) -> Generator[Any, None, None]:
-        return self.ctx.defer(ephemeral=self.ephemeral).__await__()
+        return self.do_defer().__await__()
 
     async def __aenter__(self) -> None:
-        await self.ctx.defer(ephemeral=self.ephemeral)
+        await self.do_defer()
 
     async def __aexit__(
         self,
@@ -1074,8 +1078,11 @@ class Context(discord.abc.Messageable, Generic[BotT]):
         if self.interaction.response.is_done():
             msg = await self.interaction.followup.send(**kwargs, wait=True)
         else:
-            await self.interaction.response.send_message(**kwargs)
-            msg = await self.interaction.original_response()
+            response = await self.interaction.response.send_message(**kwargs)
+            if not isinstance(response.resource, discord.InteractionMessage):
+                msg = await self.interaction.original_response()
+            else:
+                msg = response.resource
 
         if delete_after is not None:
             await msg.delete(delay=delete_after)
