@@ -24,9 +24,12 @@ DEALINGS IN THE SOFTWARE.
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Callable, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any, Callable, List, Optional, Tuple, Union, Generic
 
 from discord.errors import ClientException, DiscordException
+from discord.utils import _human_join
+
+from ._types import BotT
 
 if TYPE_CHECKING:
     from discord.abc import GuildChannel
@@ -34,7 +37,6 @@ if TYPE_CHECKING:
     from discord.types.snowflake import Snowflake, SnowflakeList
     from discord.app_commands import AppCommandError
 
-    from ._types import BotT
     from .context import Context
     from .converter import Converter
     from .cooldowns import BucketType, Cooldown
@@ -74,6 +76,7 @@ __all__ = (
     'EmojiNotFound',
     'GuildStickerNotFound',
     'ScheduledEventNotFound',
+    'SoundboardSoundNotFound',
     'PartialEmojiConversionFailure',
     'BadBoolArgument',
     'MissingRole',
@@ -233,7 +236,7 @@ class CheckFailure(CommandError):
     pass
 
 
-class CheckAnyFailure(CheckFailure):
+class CheckAnyFailure(Generic[BotT], CheckFailure):
     """Exception raised when all predicates in :func:`check_any` fail.
 
     This inherits from :exc:`CheckFailure`.
@@ -563,6 +566,24 @@ class ScheduledEventNotFound(BadArgument):
         super().__init__(f'ScheduledEvent "{argument}" not found.')
 
 
+class SoundboardSoundNotFound(BadArgument):
+    """Exception raised when the bot can not find the soundboard sound.
+
+    This inherits from :exc:`BadArgument`
+
+    .. versionadded:: 2.5
+
+    Attributes
+    -----------
+    argument: :class:`str`
+        The sound supplied by the caller that was not found
+    """
+
+    def __init__(self, argument: str) -> None:
+        self.argument: str = argument
+        super().__init__(f'SoundboardSound "{argument}" not found.')
+
+
 class BadBoolArgument(BadArgument):
     """Exception raised when a boolean argument was not convertable.
 
@@ -758,12 +779,7 @@ class MissingAnyRole(CheckFailure):
         self.missing_roles: SnowflakeList = missing_roles
 
         missing = [f"'{role}'" for role in missing_roles]
-
-        if len(missing) > 2:
-            fmt = '{}, or {}'.format(', '.join(missing[:-1]), missing[-1])
-        else:
-            fmt = ' or '.join(missing)
-
+        fmt = _human_join(missing)
         message = f'You are missing at least one of the required roles: {fmt}'
         super().__init__(message)
 
@@ -788,12 +804,7 @@ class BotMissingAnyRole(CheckFailure):
         self.missing_roles: SnowflakeList = missing_roles
 
         missing = [f"'{role}'" for role in missing_roles]
-
-        if len(missing) > 2:
-            fmt = '{}, or {}'.format(', '.join(missing[:-1]), missing[-1])
-        else:
-            fmt = ' or '.join(missing)
-
+        fmt = _human_join(missing)
         message = f'Bot is missing at least one of the required roles: {fmt}'
         super().__init__(message)
 
@@ -832,11 +843,7 @@ class MissingPermissions(CheckFailure):
         self.missing_permissions: List[str] = missing_permissions
 
         missing = [perm.replace('_', ' ').replace('guild', 'server').title() for perm in missing_permissions]
-
-        if len(missing) > 2:
-            fmt = '{}, and {}'.format(', '.join(missing[:-1]), missing[-1])
-        else:
-            fmt = ' and '.join(missing)
+        fmt = _human_join(missing, final='and')
         message = f'You are missing {fmt} permission(s) to run this command.'
         super().__init__(message, *args)
 
@@ -857,11 +864,7 @@ class BotMissingPermissions(CheckFailure):
         self.missing_permissions: List[str] = missing_permissions
 
         missing = [perm.replace('_', ' ').replace('guild', 'server').title() for perm in missing_permissions]
-
-        if len(missing) > 2:
-            fmt = '{}, and {}'.format(', '.join(missing[:-1]), missing[-1])
-        else:
-            fmt = ' and '.join(missing)
+        fmt = _human_join(missing, final='and')
         message = f'Bot requires {fmt} permission(s) to run this command.'
         super().__init__(message, *args)
 
@@ -896,11 +899,7 @@ class BadUnionArgument(UserInputError):
                 return x.__class__.__name__
 
         to_string = [_get_name(x) for x in converters]
-        if len(to_string) > 2:
-            fmt = '{}, or {}'.format(', '.join(to_string[:-1]), to_string[-1])
-        else:
-            fmt = ' or '.join(to_string)
-
+        fmt = _human_join(to_string)
         super().__init__(f'Could not convert "{param.displayed_name or param.name}" into {fmt}.')
 
 
@@ -933,11 +932,7 @@ class BadLiteralArgument(UserInputError):
         self.argument: str = argument
 
         to_string = [repr(l) for l in literals]
-        if len(to_string) > 2:
-            fmt = '{}, or {}'.format(', '.join(to_string[:-1]), to_string[-1])
-        else:
-            fmt = ' or '.join(to_string)
-
+        fmt = _human_join(to_string)
         super().__init__(f'Could not convert "{param.displayed_name or param.name}" into the literal {fmt}.')
 
 
@@ -1086,7 +1081,7 @@ class ExtensionNotFound(ExtensionError):
     """
 
     def __init__(self, name: str) -> None:
-        msg = f'Extension {name!r} could not be loaded.'
+        msg = f'Extension {name!r} could not be loaded or found.'
         super().__init__(msg, name=name)
 
 
