@@ -54,6 +54,8 @@ __all__ = (
     'Interaction',
     'InteractionMessage',
     'InteractionResponse',
+    'InteractionCallbackResponse',
+    'InteractionCallbackActivityInstance',
 )
 
 if TYPE_CHECKING:
@@ -61,6 +63,8 @@ if TYPE_CHECKING:
         Interaction as InteractionPayload,
         InteractionData,
         ApplicationCommandInteractionData,
+        InteractionCallback as InteractionCallbackPayload,
+        InteractionCallbackActivity as InteractionCallbackActivityPayload,
     )
     from .types.webhook import (
         Webhook as WebhookPayload,
@@ -90,6 +94,10 @@ if TYPE_CHECKING:
         DMChannel,
         GroupChannel,
     ]
+    InteractionCallbackResource = Union[
+        "InteractionMessage",
+        "InteractionCallbackActivityInstance",
+    ]
 
 MISSING: Any = utils.MISSING
 
@@ -192,6 +200,9 @@ class Interaction(Generic[ClientT]):
         self.command_failed: bool = False
         self._from_data(data)
 
+    def __repr__(self) -> str:
+        return f'<{self.__class__.__name__} id={self.id} type={self.type!r} guild_id={self.guild_id!r} user={self.user!r}>'
+
     def _from_data(self, data: InteractionPayload):
         self.id: int = int(data['id'])
         self.type: InteractionType = try_enum(InteractionType, data['type'])
@@ -208,14 +219,15 @@ class Interaction(Generic[ClientT]):
             int(k): int(v) for k, v in data.get('authorizing_integration_owners', {}).items()
         }
         try:
-            self.context = AppCommandContext._from_value([data['context']])
+            value = data['context']  # pyright: ignore[reportTypedDictNotRequiredAccess]
+            self.context = AppCommandContext._from_value([value])
         except KeyError:
             self.context = AppCommandContext()
 
         self.locale: Locale = try_enum(Locale, data.get('locale', 'en-US'))
         self.guild_locale: Optional[Locale]
         try:
-            self.guild_locale = try_enum(Locale, data['guild_locale'])
+            self.guild_locale = try_enum(Locale, data['guild_locale'])  # pyright: ignore[reportTypedDictNotRequiredAccess]
         except KeyError:
             self.guild_locale = None
 
@@ -466,6 +478,7 @@ class Interaction(Generic[ClientT]):
         attachments: Sequence[Union[Attachment, File]] = MISSING,
         view: Optional[View] = MISSING,
         allowed_mentions: Optional[AllowedMentions] = None,
+        poll: Poll = MISSING,
     ) -> InteractionMessage:
         """|coro|
 
@@ -500,6 +513,14 @@ class Interaction(Generic[ClientT]):
         view: Optional[:class:`~discord.ui.View`]
             The updated view to update this message with. If ``None`` is passed then
             the view is removed.
+        poll: :class:`Poll`
+            The poll to create when editing the message.
+
+            .. versionadded:: 2.5
+
+            .. note::
+
+                This is only accepted when the response type is :attr:`InteractionResponseType.deferred_channel_message`.
 
         Raises
         -------
@@ -529,6 +550,7 @@ class Interaction(Generic[ClientT]):
             view=view,
             allowed_mentions=allowed_mentions,
             previous_allowed_mentions=previous_mentions,
+            poll=poll,
         ) as params:
             adapter = async_context.get()
             http = self._state.http
@@ -621,6 +643,106 @@ class Interaction(Generic[ClientT]):
         return await translator.translate(string, locale=locale, context=context)
 
 
+class InteractionCallbackActivityInstance:
+    """Represents an activity instance launched as an interaction response.
+
+    .. versionadded:: 2.5
+
+    Attributes
+    ----------
+    id: :class:`str`
+        The activity instance ID.
+    """
+
+    __slots__ = ('id',)
+
+    def __init__(self, data: InteractionCallbackActivityPayload) -> None:
+        self.id: str = data['id']
+
+
+class InteractionCallbackResponse(Generic[ClientT]):
+    """Represents an interaction response callback.
+
+    .. versionadded:: 2.5
+
+    Attributes
+    ----------
+    id: :class:`int`
+        The interaction ID.
+    type: :class:`InteractionResponseType`
+        The interaction callback response type.
+    resource: Optional[Union[:class:`InteractionMessage`, :class:`InteractionCallbackActivityInstance`]]
+        The resource that the interaction response created. If a message was sent, this will be
+        a :class:`InteractionMessage`. If an activity was launched this will be a
+        :class:`InteractionCallbackActivityInstance`. In any other case, this will be ``None``.
+    message_id: Optional[:class:`int`]
+        The message ID of the resource. Only available if the resource is a :class:`InteractionMessage`.
+    activity_id: Optional[:class:`str`]
+        The activity ID of the resource. Only available if the resource is a :class:`InteractionCallbackActivityInstance`.
+    """
+
+    __slots__ = (
+        '_state',
+        '_parent',
+        'type',
+        'id',
+        '_thinking',
+        '_ephemeral',
+        'message_id',
+        'activity_id',
+        'resource',
+    )
+
+    def __init__(
+        self,
+        *,
+        data: InteractionCallbackPayload,
+        parent: Interaction[ClientT],
+        state: ConnectionState,
+        type: InteractionResponseType,
+    ) -> None:
+        self._state: ConnectionState = state
+        self._parent: Interaction[ClientT] = parent
+        self.type: InteractionResponseType = type
+        self._update(data)
+
+    def _update(self, data: InteractionCallbackPayload) -> None:
+        interaction = data['interaction']
+
+        self.id: int = int(interaction['id'])
+        self._thinking: bool = interaction.get('response_message_loading', False)
+        self._ephemeral: bool = interaction.get('response_message_ephemeral', False)
+
+        self.message_id: Optional[int] = utils._get_as_snowflake(interaction, 'response_message_id')
+        self.activity_id: Optional[str] = interaction.get('activity_instance_id')
+
+        self.resource: Optional[InteractionCallbackResource] = None
+
+        resource = data.get('resource')
+        if resource is not None:
+
+            self.type = try_enum(InteractionResponseType, resource['type'])
+
+            message = resource.get('message')
+            activity_instance = resource.get('activity_instance')
+            if message is not None:
+                self.resource = InteractionMessage(
+                    state=self._state,
+                    channel=self._parent.channel,  # type: ignore # channel should be the correct type here
+                    data=message,
+                )
+            elif activity_instance is not None:
+                self.resource = InteractionCallbackActivityInstance(activity_instance)
+
+    def is_thinking(self) -> bool:
+        """:class:`bool`: Whether the response was a thinking defer."""
+        return self._thinking
+
+    def is_ephemeral(self) -> bool:
+        """:class:`bool`: Whether the response was ephemeral."""
+        return self._ephemeral
+
+
 class InteractionResponse(Generic[ClientT]):
     """Represents a Discord interaction response.
 
@@ -650,7 +772,12 @@ class InteractionResponse(Generic[ClientT]):
         """:class:`InteractionResponseType`: The type of response that was sent, ``None`` if response is not done."""
         return self._response_type
 
-    async def defer(self, *, ephemeral: bool = False, thinking: bool = False) -> None:
+    async def defer(
+        self,
+        *,
+        ephemeral: bool = False,
+        thinking: bool = False,
+    ) -> Optional[InteractionCallbackResponse[ClientT]]:
         """|coro|
 
         Defers the interaction response.
@@ -664,6 +791,9 @@ class InteractionResponse(Generic[ClientT]):
         - :attr:`InteractionType.component`
         - :attr:`InteractionType.modal_submit`
 
+        .. versionchanged:: 2.5
+            This now returns a :class:`InteractionCallbackResponse` instance.
+
         Parameters
         -----------
         ephemeral: :class:`bool`
@@ -682,6 +812,11 @@ class InteractionResponse(Generic[ClientT]):
             Deferring the interaction failed.
         InteractionResponded
             This interaction has already been responded to before.
+
+        Returns
+        -------
+        Optional[:class:`InteractionCallbackResponse`]
+            The interaction callback resource, or ``None``.
         """
         if self._response_type:
             raise InteractionResponded(self._parent)
@@ -706,7 +841,7 @@ class InteractionResponse(Generic[ClientT]):
             adapter = async_context.get()
             params = interaction_response_params(type=defer_type, data=data)
             http = parent._state.http
-            await adapter.create_interaction_response(
+            response = await adapter.create_interaction_response(
                 parent.id,
                 parent.token,
                 session=parent._session,
@@ -715,6 +850,12 @@ class InteractionResponse(Generic[ClientT]):
                 params=params,
             )
             self._response_type = InteractionResponseType(defer_type)
+            return InteractionCallbackResponse(
+                data=response,
+                parent=self._parent,
+                state=self._parent._state,
+                type=self._response_type,
+            )
 
     async def pong(self) -> None:
         """|coro|
@@ -764,11 +905,14 @@ class InteractionResponse(Generic[ClientT]):
         silent: bool = False,
         delete_after: Optional[float] = None,
         poll: Poll = MISSING,
-    ) -> None:
+    ) -> InteractionCallbackResponse[ClientT]:
         """|coro|
 
         Responds to this interaction by sending a message.
 
+        .. versionchanged:: 2.5
+            This now returns a :class:`InteractionCallbackResponse` instance.
+
         Parameters
         -----------
         content: Optional[:class:`str`]
@@ -822,6 +966,11 @@ class InteractionResponse(Generic[ClientT]):
             The length of ``embeds`` was invalid.
         InteractionResponded
             This interaction has already been responded to before.
+
+        Returns
+        -------
+        :class:`InteractionCallbackResponse`
+            The interaction callback data.
         """
         if self._response_type:
             raise InteractionResponded(self._parent)
@@ -852,7 +1001,7 @@ class InteractionResponse(Generic[ClientT]):
         )
 
         http = parent._state.http
-        await adapter.create_interaction_response(
+        response = await adapter.create_interaction_response(
             parent.id,
             parent.token,
             session=parent._session,
@@ -883,6 +1032,13 @@ class InteractionResponse(Generic[ClientT]):
 
             asyncio.create_task(inner_call())
 
+        return InteractionCallbackResponse(
+            data=response,
+            parent=self._parent,
+            state=self._parent._state,
+            type=self._response_type,
+        )
+
     async def edit_message(
         self,
         *,
@@ -894,12 +1050,15 @@ class InteractionResponse(Generic[ClientT]):
         allowed_mentions: Optional[AllowedMentions] = MISSING,
         delete_after: Optional[float] = None,
         suppress_embeds: bool = MISSING,
-    ) -> None:
+    ) -> Optional[InteractionCallbackResponse[ClientT]]:
         """|coro|
 
         Responds to this interaction by editing the original message of
         a component or modal interaction.
 
+        .. versionchanged:: 2.5
+            This now returns a :class:`InteractionCallbackResponse` instance.
+
         Parameters
         -----------
         content: Optional[:class:`str`]
@@ -945,6 +1104,11 @@ class InteractionResponse(Generic[ClientT]):
             You specified both ``embed`` and ``embeds``.
         InteractionResponded
             This interaction has already been responded to before.
+
+        Returns
+        -------
+        Optional[:class:`InteractionCallbackResponse`]
+            The interaction callback data, or ``None`` if editing the message was not possible.
         """
         if self._response_type:
             raise InteractionResponded(self._parent)
@@ -987,7 +1151,7 @@ class InteractionResponse(Generic[ClientT]):
         )
 
         http = parent._state.http
-        await adapter.create_interaction_response(
+        response = await adapter.create_interaction_response(
             parent.id,
             parent.token,
             session=parent._session,
@@ -1012,11 +1176,21 @@ class InteractionResponse(Generic[ClientT]):
 
             asyncio.create_task(inner_call())
 
-    async def send_modal(self, modal: Modal, /) -> None:
+        return InteractionCallbackResponse(
+            data=response,
+            parent=self._parent,
+            state=self._parent._state,
+            type=self._response_type,
+        )
+
+    async def send_modal(self, modal: Modal, /) -> InteractionCallbackResponse[ClientT]:
         """|coro|
 
         Responds to this interaction by sending a modal.
 
+        .. versionchanged:: 2.5
+            This now returns a :class:`InteractionCallbackResponse` instance.
+
         Parameters
         -----------
         modal: :class:`~discord.ui.Modal`
@@ -1028,6 +1202,11 @@ class InteractionResponse(Generic[ClientT]):
             Sending the modal failed.
         InteractionResponded
             This interaction has already been responded to before.
+
+        Returns
+        -------
+        :class:`InteractionCallbackResponse`
+            The interaction callback data.
         """
         if self._response_type:
             raise InteractionResponded(self._parent)
@@ -1038,7 +1217,7 @@ class InteractionResponse(Generic[ClientT]):
         http = parent._state.http
 
         params = interaction_response_params(InteractionResponseType.modal.value, modal.to_dict())
-        await adapter.create_interaction_response(
+        response = await adapter.create_interaction_response(
             parent.id,
             parent.token,
             session=parent._session,
@@ -1050,6 +1229,13 @@ class InteractionResponse(Generic[ClientT]):
             self._parent._state.store_view(modal)
         self._response_type = InteractionResponseType.modal
 
+        return InteractionCallbackResponse(
+            data=response,
+            parent=self._parent,
+            state=self._parent._state,
+            type=self._response_type,
+        )
+
     async def autocomplete(self, choices: Sequence[Choice[ChoiceT]]) -> None:
         """|coro|
 
@@ -1151,6 +1337,7 @@ class InteractionMessage(Message):
         view: Optional[View] = MISSING,
         allowed_mentions: Optional[AllowedMentions] = None,
         delete_after: Optional[float] = None,
+        poll: Poll = MISSING,
     ) -> InteractionMessage:
         """|coro|
 
@@ -1185,6 +1372,15 @@ class InteractionMessage(Message):
             then it is silently ignored.
 
             .. versionadded:: 2.2
+        poll: :class:`~discord.Poll`
+            The poll to create when editing the message.
+
+            .. versionadded:: 2.5
+
+            .. note::
+
+                This is only accepted if the interaction response's :attr:`InteractionResponse.type`
+                attribute is :attr:`InteractionResponseType.deferred_channel_message`.
 
         Raises
         -------
@@ -1209,6 +1405,7 @@ class InteractionMessage(Message):
             attachments=attachments,
             view=view,
             allowed_mentions=allowed_mentions,
+            poll=poll,
         )
         if delete_after is not None:
             await self.delete(delay=delete_after)
