@@ -141,9 +141,12 @@ class Permissions(BaseFlags):
 
         self.value = permissions
         for key, value in kwargs.items():
-            if key not in self.VALID_FLAGS:
-                raise TypeError(f'{key!r} is not a valid permission name.')
-            setattr(self, key, value)
+            try:
+                flag = self.VALID_FLAGS[key]
+            except KeyError:
+                raise TypeError(f'{key!r} is not a valid permission name.') from None
+            else:
+                self._set_flag(flag, value)
 
     def is_subset(self, other: Permissions) -> bool:
         """Returns ``True`` if self has the same or fewer permissions as other."""
@@ -183,7 +186,8 @@ class Permissions(BaseFlags):
         """A factory method that creates a :class:`Permissions` with all
         permissions set to ``True``.
         """
-        return cls(0b11111111111111111111111111111111111111111111111)
+        # Some of these are 0 because we don't want to set unnecessary bits
+        return cls(0b0000_0000_0000_0110_0111_1111_1111_1111_1111_1111_1111_1111_1111_1111_1111_1111)
 
     @classmethod
     def _timeout_mask(cls) -> int:
@@ -204,6 +208,22 @@ class Permissions(BaseFlags):
         base.send_messages_in_threads = False
         return base
 
+    @classmethod
+    def _user_installed_permissions(cls, *, in_guild: bool) -> Self:
+        base = cls.none()
+        base.send_messages = True
+        base.attach_files = True
+        base.embed_links = True
+        base.external_emojis = True
+        base.send_voice_messages = True
+        if in_guild:
+            # Logically this is False but if not set to True,
+            # permissions just become 0.
+            base.read_messages = True
+            base.send_tts_messages = True
+            base.send_messages_in_threads = True
+        return base
+
     @classmethod
     def all_channel(cls) -> Self:
         """A :class:`Permissions` with all channel-specific permissions set to
@@ -220,6 +240,10 @@ class Permissions(BaseFlags):
         - :attr:`ban_members`
         - :attr:`administrator`
         - :attr:`create_expressions`
+        - :attr:`moderate_members`
+        - :attr:`create_events`
+        - :attr:`manage_events`
+        - :attr:`view_creator_monetization_analytics`
 
         .. versionchanged:: 1.7
            Added :attr:`stream`, :attr:`priority_speaker` and :attr:`use_application_commands` permissions.
@@ -231,8 +255,12 @@ class Permissions(BaseFlags):
 
         .. versionchanged:: 2.3
            Added :attr:`use_soundboard`, :attr:`create_expressions` permissions.
+
+        .. versionchanged:: 2.4
+            Added :attr:`send_polls`, :attr:`send_voice_messages`, attr:`use_external_sounds`,
+            :attr:`use_embedded_activities`, and :attr:`use_external_apps` permissions.
         """
-        return cls(0b01000111110110110011111101111111111101010001)
+        return cls(0b0000_0000_0000_0110_0110_0100_1111_1101_1011_0011_1111_0111_1111_1111_0101_0001)
 
     @classmethod
     def general(cls) -> Self:
@@ -247,8 +275,11 @@ class Permissions(BaseFlags):
 
         .. versionchanged:: 2.3
             Added :attr:`create_expressions` permission.
+
+        .. versionchanged:: 2.4
+            Added :attr:`view_creator_monetization_analytics` permission.
         """
-        return cls(0b10000000000001110000000010000000010010110000)
+        return cls(0b0000_0000_0000_0000_0000_1010_0000_0000_0111_0000_0000_1000_0000_0100_1011_0000)
 
     @classmethod
     def membership(cls) -> Self:
@@ -257,7 +288,7 @@ class Permissions(BaseFlags):
 
         .. versionadded:: 1.7
         """
-        return cls(0b10000000000001100000000000000000000000111)
+        return cls(0b0000_0000_0000_0000_0000_0001_0000_0000_0000_1100_0000_0000_0000_0000_0000_0111)
 
     @classmethod
     def text(cls) -> Self:
@@ -274,14 +305,17 @@ class Permissions(BaseFlags):
 
         .. versionchanged:: 2.3
             Added :attr:`send_voice_messages` permission.
+
+        .. versionchanged:: 2.4
+            Added :attr:`send_polls` and :attr:`use_external_apps` permissions.
         """
-        return cls(0b10000000111110010000000000001111111100001000000)
+        return cls(0b0000_0000_0000_0110_0100_0000_0111_1100_1000_0000_0000_0111_1111_1000_0100_0000)
 
     @classmethod
     def voice(cls) -> Self:
         """A factory method that creates a :class:`Permissions` with all
         "Voice" permissions from the official Discord UI set to ``True``."""
-        return cls(0b1001001000000000000011111100000000001100000000)
+        return cls(0b0000_0000_0000_0000_0010_0100_1000_0000_0000_0011_1111_0000_0000_0011_0000_0000)
 
     @classmethod
     def stage(cls) -> Self:
@@ -306,7 +340,7 @@ class Permissions(BaseFlags):
         .. versionchanged:: 2.0
             Added :attr:`manage_channels` permission and removed :attr:`request_to_speak` permission.
         """
-        return cls(0b1010000000000000000010000)
+        return cls(0b0000_0000_0000_0000_0000_0000_0000_0000_0000_0001_0100_0000_0000_0000_0001_0000)
 
     @classmethod
     def elevated(cls) -> Self:
@@ -327,7 +361,16 @@ class Permissions(BaseFlags):
 
         .. versionadded:: 2.0
         """
-        return cls(0b10000010001110000000000000010000000111110)
+        return cls(0b0000_0000_0000_0000_0000_0001_0000_0100_0111_0000_0000_0000_0010_0000_0011_1110)
+
+    @classmethod
+    def events(cls) -> Self:
+        """A factory method that creates a :class:`Permissions` with all
+        "Events" permissions from the official Discord UI set to ``True``.
+
+        .. versionadded:: 2.4
+        """
+        return cls(0b0000_0000_0000_0000_0001_0000_0000_0010_0000_0000_0000_0000_0000_0000_0000_0000)
 
     @classmethod
     def advanced(cls) -> Self:
@@ -351,8 +394,9 @@ class Permissions(BaseFlags):
             A list of key/value pairs to bulk update permissions with.
         """
         for key, value in kwargs.items():
-            if key in self.VALID_FLAGS:
-                setattr(self, key, value)
+            flag = self.VALID_FLAGS.get(key)
+            if flag is not None:
+                self._set_flag(flag, value)
 
     def handle_overwrite(self, allow: int, deny: int) -> None:
         # Basically this is what's happening here.
@@ -668,6 +712,14 @@ class Permissions(BaseFlags):
         """
         return 1 << 40
 
+    @flag_value
+    def view_creator_monetization_analytics(self) -> int:
+        """:class:`bool`: Returns ``True`` if a user can view role subscription insights.
+
+        .. versionadded:: 2.4
+        """
+        return 1 << 41
+
     @flag_value
     def use_soundboard(self) -> int:
         """:class:`bool`: Returns ``True`` if a user can use the soundboard.
@@ -684,6 +736,14 @@ class Permissions(BaseFlags):
         """
         return 1 << 43
 
+    @flag_value
+    def create_events(self) -> int:
+        """:class:`bool`: Returns ``True`` if a user can create guild events.
+
+        .. versionadded:: 2.4
+        """
+        return 1 << 44
+
     @flag_value
     def use_external_sounds(self) -> int:
         """:class:`bool`: Returns ``True`` if a user can use sounds from other guilds.
@@ -700,6 +760,30 @@ class Permissions(BaseFlags):
         """
         return 1 << 46
 
+    @flag_value
+    def send_polls(self) -> int:
+        """:class:`bool`: Returns ``True`` if a user can send poll messages.
+
+        .. versionadded:: 2.4
+        """
+        return 1 << 49
+
+    @make_permission_alias('send_polls')
+    def create_polls(self) -> int:
+        """:class:`bool`: An alias for :attr:`send_polls`.
+
+        .. versionadded:: 2.4
+        """
+        return 1 << 49
+
+    @flag_value
+    def use_external_apps(self) -> int:
+        """:class:`bool`: Returns ``True`` if a user can use external apps.
+
+        .. versionadded:: 2.4
+        """
+        return 1 << 50
+
 
 def _augment_from_permissions(cls):
     cls.VALID_NAMES = set(Permissions.VALID_FLAGS)
@@ -819,6 +903,10 @@ class PermissionOverwrite:
         use_external_sounds: Optional[bool]
         send_voice_messages: Optional[bool]
         create_expressions: Optional[bool]
+        create_events: Optional[bool]
+        send_polls: Optional[bool]
+        create_polls: Optional[bool]
+        use_external_apps: Optional[bool]
 
     def __init__(self, **kwargs: Optional[bool]):
         self._values: Dict[str, Optional[bool]] = {}
