@@ -24,6 +24,12 @@ DEALINGS IN THE SOFTWARE.
 
 from .snowflake import Snowflake
 from typing import Literal, Optional, TypedDict
+from typing_extensions import NotRequired
+
+
+class AvatarDecorationData(TypedDict):
+    asset: str
+    sku_id: Snowflake
 
 
 class PartialUser(TypedDict):
@@ -32,9 +38,10 @@ class PartialUser(TypedDict):
     discriminator: str
     avatar: Optional[str]
     global_name: Optional[str]
+    avatar_decoration_data: NotRequired[AvatarDecorationData]
 
 
-PremiumType = Literal[0, 1, 2]
+PremiumType = Literal[0, 1, 2, 3]
 
 
 class User(PartialUser, total=False):
