@@ -31,7 +31,7 @@ from .asset import Asset
 from .colour import Colour
 from .enums import DefaultAvatar
 from .flags import PublicUserFlags
-from .utils import snowflake_time, _bytes_to_base64_data, MISSING
+from .utils import snowflake_time, _bytes_to_base64_data, MISSING, _get_as_snowflake
 
 if TYPE_CHECKING:
     from typing_extensions import Self
@@ -43,10 +43,7 @@ if TYPE_CHECKING:
     from .message import Message
     from .state import ConnectionState
     from .types.channel import DMChannel as DMChannelPayload
-    from .types.user import (
-        PartialUser as PartialUserPayload,
-        User as UserPayload,
-    )
+    from .types.user import PartialUser as PartialUserPayload, User as UserPayload, AvatarDecorationData
 
 
 __all__ = (
@@ -73,6 +70,7 @@ class BaseUser(_UserTag):
         'system',
         '_public_flags',
         '_state',
+        '_avatar_decoration_data',
     )
 
     if TYPE_CHECKING:
@@ -87,6 +85,7 @@ class BaseUser(_UserTag):
         _banner: Optional[str]
         _accent_colour: Optional[int]
         _public_flags: int
+        _avatar_decoration_data: Optional[AvatarDecorationData]
 
     def __init__(self, *, state: ConnectionState, data: Union[UserPayload, PartialUserPayload]) -> None:
         self._state = state
@@ -123,6 +122,7 @@ class BaseUser(_UserTag):
         self._public_flags = data.get('public_flags', 0)
         self.bot = data.get('bot', False)
         self.system = data.get('system', False)
+        self._avatar_decoration_data = data.get('avatar_decoration_data')
 
     @classmethod
     def _copy(cls, user: Self) -> Self:
@@ -138,6 +138,7 @@ class BaseUser(_UserTag):
         self.bot = user.bot
         self._state = user._state
         self._public_flags = user._public_flags
+        self._avatar_decoration_data = user._avatar_decoration_data
 
         return self
 
@@ -170,7 +171,7 @@ class BaseUser(_UserTag):
     @property
     def default_avatar(self) -> Asset:
         """:class:`Asset`: Returns the default avatar for a given user."""
-        if self.discriminator == '0':
+        if self.discriminator in ('0', '0000'):
             avatar_id = (self.id >> 22) % len(DefaultAvatar)
         else:
             avatar_id = int(self.discriminator) % 5
@@ -187,6 +188,30 @@ class BaseUser(_UserTag):
         """
         return self.avatar or self.default_avatar
 
+    @property
+    def avatar_decoration(self) -> Optional[Asset]:
+        """Optional[:class:`Asset`]: Returns an :class:`Asset` for the avatar decoration the user has.
+
+        If the user has not set an avatar decoration, ``None`` is returned.
+
+        .. versionadded:: 2.4
+        """
+        if self._avatar_decoration_data is not None:
+            return Asset._from_avatar_decoration(self._state, self._avatar_decoration_data['asset'])
+        return None
+
+    @property
+    def avatar_decoration_sku_id(self) -> Optional[int]:
+        """Optional[:class:`int`]: Returns the SKU ID of the avatar decoration the user has.
+
+        If the user has not set an avatar decoration, ``None`` is returned.
+
+        .. versionadded:: 2.4
+        """
+        if self._avatar_decoration_data is not None:
+            return _get_as_snowflake(self._avatar_decoration_data, 'sku_id')
+        return None
+
     @property
     def banner(self) -> Optional[Asset]:
         """Optional[:class:`Asset`]: Returns the user's banner asset, if available.
@@ -373,7 +398,9 @@ class ClientUser(BaseUser):
         self._flags = data.get('flags', 0)
         self.mfa_enabled = data.get('mfa_enabled', False)
 
-    async def edit(self, *, username: str = MISSING, avatar: Optional[bytes] = MISSING) -> ClientUser:
+    async def edit(
+        self, *, username: str = MISSING, avatar: Optional[bytes] = MISSING, banner: Optional[bytes] = MISSING
+    ) -> ClientUser:
         """|coro|
 
         Edits the current profile of the client.
@@ -385,7 +412,6 @@ class ClientUser(BaseUser):
             then the file must be opened via ``open('some_filename', 'rb')`` and
             the :term:`py:bytes-like object` is given through the use of ``fp.read()``.
 
-            The only image formats supported for uploading is JPEG and PNG.
 
         .. versionchanged:: 2.0
             The edit is no longer in-place, instead the newly edited client user is returned.
@@ -401,6 +427,13 @@ class ClientUser(BaseUser):
         avatar: Optional[:class:`bytes`]
             A :term:`py:bytes-like object` representing the image to upload.
             Could be ``None`` to denote no avatar.
+            Only image formats supported for uploading are JPEG, PNG, GIF, and WEBP.
+        banner: Optional[:class:`bytes`]
+            A :term:`py:bytes-like object` representing the image to upload.
+            Could be ``None`` to denote no banner.
+            Only image formats supported for uploading are JPEG, PNG, GIF and WEBP.
+
+            .. versionadded:: 2.4
 
         Raises
         ------
@@ -424,6 +457,12 @@ class ClientUser(BaseUser):
             else:
                 payload['avatar'] = None
 
+        if banner is not MISSING:
+            if banner is not None:
+                payload['banner'] = _bytes_to_base64_data(banner)
+            else:
+                payload['banner'] = None
+
         data: UserPayload = await self._state.http.edit_profile(payload)
         return ClientUser(state=self._state, data=data)
 
