@@ -44,7 +44,7 @@ from .. import utils
 from ..errors import HTTPException, Forbidden, NotFound, DiscordServerError
 from ..message import Message, MessageFlags
 from ..http import Route, handle_message_parameters
-from ..channel import PartialMessageable
+from ..channel import PartialMessageable, ForumTag
 
 from .async_ import BaseWebhook, _WebhookState
 
@@ -61,16 +61,19 @@ if TYPE_CHECKING:
 
     from ..file import File
     from ..embeds import Embed
+    from ..poll import Poll
     from ..mentions import AllowedMentions
     from ..message import Attachment
     from ..abc import Snowflake
     from ..state import ConnectionState
+    from ..ui import View
     from ..types.webhook import (
         Webhook as WebhookPayload,
     )
     from ..types.message import (
         Message as MessagePayload,
     )
+    from ..types.snowflake import SnowflakeList
 
     BE = TypeVar('BE', bound=BaseException)
 
@@ -288,8 +291,9 @@ class WebhookAdapter:
         files: Optional[Sequence[File]] = None,
         thread_id: Optional[int] = None,
         wait: bool = False,
+        with_components: bool = False,
     ) -> MessagePayload:
-        params = {'wait': int(wait)}
+        params = {'wait': int(wait), 'with_components': int(with_components)}
         if thread_id:
             params['thread_id'] = thread_id
         route = Route('POST', '/webhooks/{webhook_id}/{webhook_token}', webhook_id=webhook_id, webhook_token=token)
@@ -608,7 +612,7 @@ class SyncWebhook(BaseWebhook):
         self.session: Session = session
 
     def __repr__(self) -> str:
-        return f'<Webhook id={self.id!r}>'
+        return f'<Webhook id={self.id!r} type={self.type!r} name={self.name!r}>'
 
     @property
     def url(self) -> str:
@@ -870,6 +874,8 @@ class SyncWebhook(BaseWebhook):
         wait: Literal[True],
         suppress_embeds: bool = MISSING,
         silent: bool = MISSING,
+        applied_tags: List[ForumTag] = MISSING,
+        poll: Poll = MISSING,
     ) -> SyncWebhookMessage:
         ...
 
@@ -891,6 +897,8 @@ class SyncWebhook(BaseWebhook):
         wait: Literal[False] = ...,
         suppress_embeds: bool = MISSING,
         silent: bool = MISSING,
+        applied_tags: List[ForumTag] = MISSING,
+        poll: Poll = MISSING,
     ) -> None:
         ...
 
@@ -911,6 +919,9 @@ class SyncWebhook(BaseWebhook):
         wait: bool = False,
         suppress_embeds: bool = False,
         silent: bool = False,
+        applied_tags: List[ForumTag] = MISSING,
+        poll: Poll = MISSING,
+        view: View = MISSING,
     ) -> Optional[SyncWebhookMessage]:
         """Sends a message using the webhook.
 
@@ -975,6 +986,21 @@ class SyncWebhook(BaseWebhook):
             in the UI, but will not actually send a notification.
 
             .. versionadded:: 2.2
+        poll: :class:`Poll`
+            The poll to send with this message.
+
+            .. warning::
+
+                When sending a Poll via webhook, you cannot manually end it.
+
+            .. versionadded:: 2.4
+        view: :class:`~discord.ui.View`
+            The view to send with the message. This can only have URL buttons, which donnot
+            require a state to be attached to it.
+
+            If you want to send a view with any component attached to it, check :meth:`Webhook.send`.
+
+            .. versionadded:: 2.5
 
         Raises
         --------
@@ -988,8 +1014,9 @@ class SyncWebhook(BaseWebhook):
             You specified both ``embed`` and ``embeds`` or ``file`` and ``files``
             or ``thread`` and ``thread_name``.
         ValueError
-            The length of ``embeds`` was invalid or
-            there was no token associated with this webhook.
+            The length of ``embeds`` was invalid, there was no token
+            associated with this webhook or you tried to send a view
+            with components other than URL buttons.
 
         Returns
         ---------
@@ -1011,9 +1038,21 @@ class SyncWebhook(BaseWebhook):
         else:
             flags = MISSING
 
+        if view is not MISSING:
+            if not hasattr(view, '__discord_ui_view__'):
+                raise TypeError(f'expected view parameter to be of type View not {view.__class__.__name__}')
+
+            if view.is_dispatchable():
+                raise ValueError('SyncWebhook views can only contain URL buttons')
+
         if thread_name is not MISSING and thread is not MISSING:
             raise TypeError('Cannot mix thread_name and thread keyword arguments.')
 
+        if applied_tags is MISSING:
+            applied_tag_ids = MISSING
+        else:
+            applied_tag_ids: SnowflakeList = [tag.id for tag in applied_tags]
+
         with handle_message_parameters(
             content=content,
             username=username,
@@ -1027,6 +1066,9 @@ class SyncWebhook(BaseWebhook):
             allowed_mentions=allowed_mentions,
             previous_allowed_mentions=previous_mentions,
             flags=flags,
+            applied_tags=applied_tag_ids,
+            poll=poll,
+            view=view,
         ) as params:
             adapter: WebhookAdapter = _get_webhook_adapter()
             thread_id: Optional[int] = None
@@ -1042,10 +1084,18 @@ class SyncWebhook(BaseWebhook):
                 files=params.files,
                 thread_id=thread_id,
                 wait=wait,
+                with_components=view is not MISSING,
             )
 
+        msg = None
+
         if wait:
-            return self._create_message(data, thread=thread)
+            msg = self._create_message(data, thread=thread)
+
+        if poll is not MISSING and msg:
+            poll._update(msg)
+
+        return msg
 
     def fetch_message(self, id: int, /, *, thread: Snowflake = MISSING) -> SyncWebhookMessage:
         """Retrieves a single :class:`~discord.SyncWebhookMessage` owned by this webhook.
